autoExtractThreshold property
Confidence threshold for automatic extraction (0-100) Strings with confidence below this will prompt for user review
Implementation
final int autoExtractThreshold;
Confidence threshold for automatic extraction (0-100) Strings with confidence below this will prompt for user review
final int autoExtractThreshold;